Stan Math Library: stan/math/rev/core.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

core.hpp File Reference
`#include <stan/math/rev/core/autodiffstackstorage.hpp>`
`#include <stan/math/rev/core/chainable_alloc.hpp>`
`#include <stan/math/rev/core/chainablestack.hpp>`
`#include <stan/math/rev/core/ddv_vari.hpp>`
`#include <stan/math/rev/core/dv_vari.hpp>`
`#include <stan/math/rev/core/dvd_vari.hpp>`
`#include <stan/math/rev/core/dvv_vari.hpp>`
`#include <stan/math/rev/core/empty_nested.hpp>`
`#include <stan/math/rev/core/gevv_vvv_vari.hpp>`
`#include <stan/math/rev/core/grad.hpp>`
`#include <stan/math/rev/core/matrix_vari.hpp>`
`#include <stan/math/rev/core/nested_size.hpp>`
`#include <stan/math/rev/core/operator_addition.hpp>`
`#include <stan/math/rev/core/operator_divide_equal.hpp>`
`#include <stan/math/rev/core/operator_division.hpp>`
`#include <stan/math/rev/core/operator_equal.hpp>`
`#include <stan/math/rev/core/operator_greater_than.hpp>`
`#include <stan/math/rev/core/operator_greater_than_or_equal.hpp>`
`#include <stan/math/rev/core/operator_less_than.hpp>`
`#include <stan/math/rev/core/operator_less_than_or_equal.hpp>`
`#include <stan/math/rev/core/operator_minus_equal.hpp>`
`#include <stan/math/rev/core/operator_multiplication.hpp>`
`#include <stan/math/rev/core/operator_multiply_equal.hpp>`
`#include <stan/math/rev/core/operator_not_equal.hpp>`
`#include <stan/math/rev/core/operator_plus_equal.hpp>`
`#include <stan/math/rev/core/operator_subtraction.hpp>`
`#include <stan/math/rev/core/operator_unary_decrement.hpp>`
`#include <stan/math/rev/core/operator_unary_increment.hpp>`
`#include <stan/math/rev/core/operator_unary_negative.hpp>`
`#include <stan/math/rev/core/operator_unary_not.hpp>`
`#include <stan/math/rev/core/operator_unary_plus.hpp>`
`#include <stan/math/rev/core/precomp_v_vari.hpp>`
`#include <stan/math/rev/core/precomp_vv_vari.hpp>`
`#include <stan/math/rev/core/precomp_vvv_vari.hpp>`
`#include <stan/math/rev/core/precomputed_gradients.hpp>`
`#include <stan/math/rev/core/print_stack.hpp>`
`#include <stan/math/rev/core/recover_memory.hpp>`
`#include <stan/math/rev/core/recover_memory_nested.hpp>`
`#include <stan/math/rev/core/set_zero_all_adjoints.hpp>`
`#include <stan/math/rev/core/set_zero_all_adjoints_nested.hpp>`
`#include <stan/math/rev/core/start_nested.hpp>`
`#include <stan/math/rev/core/std_isinf.hpp>`
`#include <stan/math/rev/core/std_isnan.hpp>`
`#include <stan/math/rev/core/std_numeric_limits.hpp>`
`#include <stan/math/rev/core/stored_gradient_vari.hpp>`
`#include <stan/math/rev/core/v_vari.hpp>`
`#include <stan/math/rev/core/var.hpp>`
`#include <stan/math/rev/core/vari.hpp>`
`#include <stan/math/rev/core/vd_vari.hpp>`
`#include <stan/math/rev/core/vdd_vari.hpp>`
`#include <stan/math/rev/core/vdv_vari.hpp>`
`#include <stan/math/rev/core/vector_vari.hpp>`
`#include <stan/math/rev/core/vv_vari.hpp>`
`#include <stan/math/rev/core/vvd_vari.hpp>`
`#include <stan/math/rev/core/vvv_vari.hpp>`

Go to the source code of this file.

[ Stan Home Page ] © 2011–2016, Stan Development Team.